==> hazelcast-all-4.1-sources.jar: com/hazelcast/org/apache/calcite/linq4j/ExtendedOrderedQueryable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in com.hazelcast.com.liance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.com.hazelcast.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hazelcast.org.apache.calcite.linq4j;

import com.hazelcast.org.apache.calcite.linq4j.function.Function1;
import com.hazelcast.org.apache.calcite.linq4j.tree.FunctionExpression;

import java.util.Comparator;

/**
 * Extension methods for {@link OrderedQueryable}.
 *
 * @param <T> Element type
 */
public interface ExtendedOrderedQueryable<T> extends Queryable<T> {
  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * ascending order according to a key.
   */
  <TKey extends Comparable<TKey>> OrderedQueryable<T> thenBy(
      FunctionExpression<Function1<T, TKey>> keySelector);

  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * ascending order according to a key, using a specified com.hazelcast.com.arator.
   */
  <TKey> OrderedQueryable<T> thenBy(
      FunctionExpression<Function1<T, TKey>> keySelector,
      Comparator<TKey> com.hazelcast.com.arator);

  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * descending order according to a key.
   */
  <TKey extends Comparable<TKey>> OrderedQueryable<T> thenByDescending(
      FunctionExpression<Function1<T, TKey>> keySelector);

  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * descending order according to a key, using a specified com.hazelcast.com.arator.
   */
  <TKey> OrderedQueryable<T> thenByDescending(
      FunctionExpression<Function1<T, TKey>> keySelector,
      Comparator<TKey> com.hazelcast.com.arator);
}

==> hazelcast-all-4.1.5-sources.jar: com/hazelcast/org/apache/calcite/linq4j/ExtendedOrderedQueryable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hazelcast.org.apache.calcite.linq4j;

import com.hazelcast.org.apache.calcite.linq4j.function.Function1;
import com.hazelcast.org.apache.calcite.linq4j.tree.FunctionExpression;

import java.util.Comparator;

/**
 * Extension methods for {@link OrderedQueryable}.
 *
 * @param <T> Element type
 */
public interface ExtendedOrderedQueryable<T> extends Queryable<T> {
  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * ascending order according to a key.
   */
  <TKey extends Comparable<TKey>> OrderedQueryable<T> thenBy(
      FunctionExpression<Function1<T, TKey>> keySelector);

  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * ascending order according to a key, using a specified comparator.
   */
  <TKey> OrderedQueryable<T> thenBy(
      FunctionExpression<Function1<T, TKey>> keySelector,
      Comparator<TKey> comparator);

  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * descending order according to a key.
   */
  <TKey extends Comparable<TKey>> OrderedQueryable<T> thenByDescending(
      FunctionExpression<Function1<T, TKey>> keySelector);

  /**
   * Performs a subsequent ordering of the elements in a sequence in
   * descending order according to a key, using a specified comparator.
   */
  <TKey> OrderedQueryable<T> thenByDescending(
      FunctionExpression<Function1<T, TKey>> keySelector,
      Comparator<TKey> comparator);
}
